---
sidebar_label: Examples
sidebar_position: 4
---

# Representative Examples

This section describes several representative examples in ChemEx. All examples
are placed under `examples/` directory, each experiment module (see
[`Experiments`](../experiments/) section) typically has at least one
example to demonstrate its application.

import DocCardList from '@theme/DocCardList';

import {useCurrentSidebarCategory} from '@docusaurus/theme-common';

<DocCardList items={useCurrentSidebarCategory().items}/>
